==> haskell-sockaddr-0.0.1-147-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sockaddr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sockaddr
version:              0.0.1
visibility:           public
id:                   sockaddr-0.0.1-7DxZZtqa96MKQjSntk6lgG
key:                  sockaddr-0.0.1-7DxZZtqa96MKQjSntk6lgG
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Printing SockAddr
description:          Printing SockAddr
category:             Network
abi:                  f849f1b6b2c7d494a4f05750e0691ecb
exposed:              True
exposed-modules:      Network.SockAddr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sockaddr
hs-libraries:         HSsockaddr-0.0.1-7DxZZtqa96MKQjSntk6lgG
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 network-3.1.4.0-IebBekr390i8Nw6inuvzzb

haddock-interfaces:   /usr/share/doc/haskell-sockaddr/html/sockaddr.haddock
haddock-html:         /usr/share/doc/haskell-sockaddr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sockaddr-0.0.1-148-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sockaddr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sockaddr
version:              0.0.1
visibility:           public
id:                   sockaddr-0.0.1-EdJMzTwaAdXIDANQgkvI2D
key:                  sockaddr-0.0.1-EdJMzTwaAdXIDANQgkvI2D
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Printing SockAddr
description:          Printing SockAddr
category:             Network
abi:                  634bfecbbdde3dcb0b5928e97eba1f22
exposed:              True
exposed-modules:      Network.SockAddr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sockaddr
hs-libraries:         HSsockaddr-0.0.1-EdJMzTwaAdXIDANQgkvI2D
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 network-3.1.4.0-Kxe15bkS84aBmhotDoAJWo

haddock-interfaces:   /usr/share/doc/haskell-sockaddr/html/sockaddr.haddock
haddock-html:         /usr/share/doc/haskell-sockaddr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
